searchData={"items":[{"type":"module","title":"Autumn","doc":"Syntax highlighter powered by Tree-sitter and Neovim themes.\n \n\n \n   https://autumnus.dev","ref":"Autumn.html"},{"type":"module","title":"Features - Autumn","doc":"- 🌳 60+ languages with tree-sitter parsing\n- 🎨 100+ Neovim themes\n- 📝 HTML output with inline or linked styles\n- 🖥️ Terminal output with ANSI colors\n- 🔍 Language auto-detection\n- 🎯 Customizable formatting options","ref":"Autumn.html#module-features"},{"type":"module","title":"Installation - Autumn","doc":"```elixir\ndef deps do\n  [\n    {:autumn, \"~> 0.3\"}\n  ]\nend\n```","ref":"Autumn.html#module-installation"},{"type":"module","title":"Usage - Autumn","doc":"","ref":"Autumn.html#module-usage"},{"type":"module","title":"Basic Usage (HTML Inline) - Autumn","doc":"```elixir\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\")\n~s|    Atom  .  to_string  (  :elixir  ) \n   |\n```\n\nSee the HTML Linked and Terminal formatters below for more options.","ref":"Autumn.html#module-basic-usage-html-inline"},{"type":"module","title":"Language Auto-detection - Autumn","doc":"```elixir\niex> Autumn.highlight!(\"#!/usr/bin/env bash\\nID=1\")\n~s|    #!/usr/bin/env bash \n   ID  =  1 \n   |\n```","ref":"Autumn.html#module-language-auto-detection"},{"type":"module","title":"Themes - Autumn","doc":"Themes are sourced from popular Neovim colorschemes.\n\nUse `Autumn.available_themes/0` to list all available themes. You can specify a theme by name directly in the `:theme` option, or use `Autumn.Theme.get/1` to get a specific theme struct if you need to inspect or manipulate its styles.\n\n```elixir\n# Using theme name\niex> Autumn.highlight!(\"setTimeout(fun, 5000);\", language: \"js\", theme: \"github_light\")\n~s|    setTimeout  (  fun  ,   5000  )  ; \n   |\n\n# Using theme struct\niex> theme = Autumn.Theme.get(\"github_light\")\niex> Autumn.highlight!(\"setTimeout(fun, 5000);\", language: \"js\", theme: theme)\n```","ref":"Autumn.html#module-themes"},{"type":"module","title":"Incomplete or Malformed code - Autumn","doc":"It's also capable of handling incomplete or malformed code, useful for streaming like in a ChatGPT interface:\n\n```elixir\niex> Autumn.highlight!(\"const header = document.getEl\", language: \"js\")\n~s|    const   header   =   document  .  getEl \n   |\n```","ref":"Autumn.html#module-incomplete-or-malformed-code"},{"type":"module","title":"Formatters - Autumn","doc":"Autumn supports three output formatters:\n\nBoth HTML formatters wrap each line in a ` ` element with a `data-line` attribute containing the line number, making it easy to add line numbers or implement line-based features in your application.","ref":"Autumn.html#module-formatters"},{"type":"module","title":"HTML Inline (Default) - Autumn","doc":"Generates HTML with inline styles for each token:\n\n```elixir\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: :html_inline)\n# or with options\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: {:html_inline, pre_class: \"my-code\", italic: true, include_highlights: true})\n```\n\nOptions:\n- `:pre_class` - CSS class for the ` ` tag\n- `:italic` - enable italic styles\n- `:include_highlights` - include highlight scope names in `data-highlight` attributes","ref":"Autumn.html#module-html-inline-default"},{"type":"module","title":"HTML Linked - Autumn","doc":"Generates HTML with CSS classes for styling:\n\n```elixir\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: :html_linked)\n# or with options\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: {:html_linked, pre_class: \"my-code\"})\n```\n\nOptions:\n- `:pre_class` - CSS class for the ` ` tag\n\nTo use linked styles, you need to include one of the [available CSS themes](https://github.com/leandrocp/autumn/tree/main/priv/static/css) in your app.\n\nFor Phoenix apps, add this to your `endpoint.ex`:\n\n```elixir\nplug Plug.Static,\n  at: \"/themes\",\n  from: {:autumn, \"priv/static/css/\"},\n  only: [\"dracula.css\"] # choose any theme you want\n```\n\nThen add the stylesheet to your template:\n\n```html\n \n```","ref":"Autumn.html#module-html-linked"},{"type":"module","title":"Terminal - Autumn","doc":"Generates ANSI escape codes for terminal output:\n\n```elixir\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: :terminal)\n# or with options\niex> Autumn.highlight!(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: {:terminal, italic: true})\n```\n\nOptions:\n- `:italic` - enable italic styles (if supported by your terminal)","ref":"Autumn.html#module-terminal"},{"type":"module","title":"Samples - Autumn","doc":"Visit https://autumnus.dev to check out some examples.","ref":"Autumn.html#module-samples"},{"type":"module","title":"Looking for help with your Elixir project? - Autumn","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"Autumn.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - Autumn","doc":"* [Logo](https://www.flaticon.com/free-icons/fall) created by by pongsakornRed - Flaticon\n* [Logo font](https://fonts.google.com/specimen/Sacramento) designed by [Astigmatic](http://www.astigmatic.com)\n* [Makeup](https://hex.pm/packages/makeup) for setting up the baseline and for the inspiration\n* [Inkjet](https://crates.io/crates/inkjet) for the Rust implementation up to v0.2 and for the inspiration","ref":"Autumn.html#module-acknowledgements"},{"type":"function","title":"Autumn.available_languages/0","doc":"Returns the list of all available languages.","ref":"Autumn.html#available_languages/0"},{"type":"function","title":"Example - Autumn.available_languages/0","doc":"iex> Autumn.available_languages()\n    %{\n      \"diff\" => {\"Diff\", [\"*.diff\"]},\n      \"lua\" => {\"Lua\", [\"*.lua\"]},\n      \"javascript\" => {\"JavaScript\", [\"*.cjs\", \"*.js\", \"*.mjs\", \"*.snap\", \"*.jsx\"]},\n      \"elixir\" => {\"Elixir\", [\"*.ex\", \"*.exs\"]},\n      ...\n    }\n\n    iex> Autumn.available_languages()[\"elixir\"]\n    {\"Elixir\", [\"*.ex\", \"*.exs\"]}","ref":"Autumn.html#available_languages/0-example"},{"type":"function","title":"Autumn.available_themes/0","doc":"Returns the list of all available themes.\n\nUse `Autumn.Theme.get/1` to get the actual theme struct.","ref":"Autumn.html#available_themes/0"},{"type":"function","title":"Example - Autumn.available_themes/0","doc":"iex> Autumn.available_themes()\n    [\"github_light\", \"github_dark\", \"catppuccin_frappe\", \"catppuccin_latte\", \"nightfox\", ...]","ref":"Autumn.html#available_themes/0-example"},{"type":"type","title":"Autumn.formatter/0","doc":"Highlighter formatter and its options.\n\nAvailable formatters: `:html_inline`, `:html_linked`, `:terminal`\n\n* `:html_inline` - generates ` ` tags with inline styles for each token, for example: ` Atom `.\n* `:html_linked` - generates ` ` tags with `class` representing the token type, for example: ` Atom `.\n   Must link an external CSS in order to render colors, see more at [HTML Linked](https://hexdocs.pm/autumn/Autumn.html#module-html-linked).\n* `:terminal` - generates ANSI escape codes for terminal output.\n\nYou can either pass the formatter as an atom to use default options or a tuple with the formatter name and options, so both are equivalent:\n\n    # passing only the formatter name like below:\n    :html_inline\n    # is the same as passing an empty list of options:\n    {:html_inline, []}","ref":"Autumn.html#t:formatter/0"},{"type":"type","title":"Available Options: - Autumn.formatter/0","doc":"* `html_inline`:\n\n    - `:theme` (`t:theme/0` - default: `nil`) - the theme to apply styles on the highlighted source code.\n    - `:pre_class` (`t:String.t/0` - default: `nil`) - the CSS class to append into the wrapping ` ` tag.\n    - `:italic` (`t:boolean/0` - default: `false`) - enable italic style for the highlighted code.\n    - `:include_highlights` (`t:boolean/0` - default: `false`) - include the highlight scope name in a `data-highlight` attribute. Useful for debugging.\n\n* `html_linked`:\n\n    - `:pre_class` (`t:String.t/0` - default: `nil`) - the CSS class to append into the wrapping ` ` tag.\n\n\n* `terminal`:\n\n    - `:theme` (`t:theme/0` - default: `nil`) - the theme to apply styles on the highlighted source code.","ref":"Autumn.html#t:formatter/0-available-options"},{"type":"type","title":"Examples - Autumn.formatter/0","doc":":html_inline\n\n    {:html_inline, theme: \"onedark\", pre_class: \"example-01\", include_highlights: true}\n\n    {:html_linked, pre_class: \"example-01\"}\n\n    :terminal\n\n    {:terminal, theme: \"github_light\"}\n\nSee https://docs.rs/autumnus/latest/autumnus/enum.FormatterOption.html for more info.","ref":"Autumn.html#t:formatter/0-examples"},{"type":"function","title":"Autumn.formatter_schema/0","doc":"","ref":"Autumn.html#formatter_schema/0"},{"type":"function","title":"Autumn.highlight/2","doc":"Highlights `source` code and outputs into a formatted string.","ref":"Autumn.html#highlight/2"},{"type":"function","title":"Options - Autumn.highlight/2","doc":"See `t:options/0`.","ref":"Autumn.html#highlight/2-options"},{"type":"function","title":"Examples - Autumn.highlight/2","doc":"Defining the language name:\n\n    iex> Autumn.highlight(\"Atom.to_string(:elixir)\", language: \"elixir\")\n    {:ok,\n     ~s|    Atom  .  to_string  (  :elixir  ) \n        |\n    }\n\nGuessing the language based on the provided source code:\n\n    iex> Autumn.highlight(\"#!/usr/bin/env bash\\nID=1\")\n    {:ok,\n     ~s|    #!/usr/bin/env bash \n        ID  =  1 \n        |\n    }\n\nWith custom options:\n\n    iex> Autumn.highlight(\"Atom.to_string(:elixir)\", language: \"example.ex\", formatter: {:html_inline, pre_class: \"example-elixir\"})\n    {:ok,\n     ~s|    Atom  .  to_string  (  :elixir  ) \n        |\n    }\n\nTerminal formatter:\n\n    iex> Autumn.highlight(\"Atom.to_string(:elixir)\", language: \"elixir\", formatter: :terminal)\n    {:ok, \"\u001B[0m\u001B[38;2;229;192;123mAtom\u001B[0m\u001B[0m\u001B[38;2;86;182;194m.\u001B[0m\u001B[0m\u001B[38;2;97;175;239mto_string\u001B[0m\u001B[0m\u001B[38;2;198;120;221m(\u001B[0m\u001B[0m\u001B[38;2;224;108;117m:elixir\u001B[0m\u001B[0m\u001B[38;2;198;120;221m)\u001B[0m\"}\n\nSee https://docs.rs/autumnus/latest/autumnus/fn.highlight.html for more info.","ref":"Autumn.html#highlight/2-examples"},{"type":"function","title":"Autumn.highlight/3","doc":"","ref":"Autumn.html#highlight/3"},{"type":"function","title":"Autumn.highlight!/2","doc":"Same as `highlight/2` but raises in case of failure.","ref":"Autumn.html#highlight!/2"},{"type":"function","title":"Autumn.highlight!/3","doc":"","ref":"Autumn.html#highlight!/3"},{"type":"type","title":"Autumn.language/0","doc":"A language name, filename, or path with extension.","ref":"Autumn.html#t:language/0"},{"type":"type","title":"Examples - Autumn.language/0","doc":"- \"elixir\"\n    - \".ex\"\n    - \"app.ex\"\n    - \"lib/app.ex\"","ref":"Autumn.html#t:language/0-examples"},{"type":"type","title":"Autumn.options/0","doc":"* `:language` (`t:Autumn.language/0`) - The language used to highlight source code.\n  You can also pass a filename or extension, for eg: `\"enum.ex\"` or just `\"ex\"`. If no language is provided, the highlighter will\n  try to guess it based on the content of the given source code. Use `Autumn.available_languages/0` to list all available languages. The default value is `nil`.\n\n* `:formatter` (`t:Autumn.formatter/0`) - Formatter to apply on the highlighted source code. See the type doc for more info. The default value is `{:html_inline, [theme: \"onedark\"]}`.\n\n* `:theme` - *This option is deprecated. Use :formatter instead.*\n\n* `:inline_style` (`t:boolean/0`) - *This option is deprecated. Use :formatter instead.*\n\n* `:pre_class` - *This option is deprecated. Use :formatter instead.*\n\n\n\nSee each option type for more info.","ref":"Autumn.html#t:options/0"},{"type":"function","title":"Autumn.options_schema/0","doc":"","ref":"Autumn.html#options_schema/0"},{"type":"type","title":"Autumn.theme/0","doc":"Theme used to apply styles on the highlighted source code.\n\nSee `Autumn.available_themes/0` to list all available themes or check out a list of [available themes](https://docs.rs/autumnus/latest/autumnus/#themes-available).","ref":"Autumn.html#t:theme/0"},{"type":"module","title":"Autumn.Theme","doc":"A Neovim theme.\n\nContains the name, appearance, and a map of highlight `Autumn.Theme.Style`'s.\n\nAutumn bundles the most popular themes from the Neovim community,\nyou can see the full list with `Autumn.available_themes/0` and\nthen fetch one of the bundled themes with `Autumn.Theme.get/1`.\n\nOr check out all the [available themes](https://docs.rs/autumnus/latest/autumnus/#themes-available).","ref":"Autumn.Theme.html"},{"type":"module","title":"Example - Autumn.Theme","doc":"%Autumn.Theme{\n       name: \"github_light\",\n       appearance: \"light\",\n       highlights: %{\n         \"function.macro\" => %Autumn.Theme.Style{\n           fg: \"#6639ba\",\n           bg: nil,\n           underline: false,\n           bold: false,\n           italic: false,\n           strikethrough: false\n         },\n         \"variable.builtin\" => %Autumn.Theme.Style{\n           fg: \"#0550ae\",\n           bg: nil,\n           underline: false,\n           bold: false,\n           italic: false,\n           strikethrough: false\n         },\n         \"character\" => %Autumn.Theme.Style{\n           fg: \"#0a3069\",\n           bg: nil,\n           underline: false,\n           bold: false,\n           italic: false,\n           strikethrough: false\n         },\n         ...\n       }\n    }","ref":"Autumn.Theme.html#module-example"},{"type":"function","title":"Autumn.Theme.get/2","doc":"Get a theme by name.","ref":"Autumn.Theme.html#get/2"},{"type":"type","title":"Autumn.Theme.t/0","doc":"","ref":"Autumn.Theme.html#t:t/0"},{"type":"module","title":"Autumn.Theme.Style","doc":"A highlight style.\n\nContains the colors and styles of each highlight of a theme.","ref":"Autumn.Theme.Style.html"},{"type":"type","title":"Autumn.Theme.Style.t/0","doc":"","ref":"Autumn.Theme.Style.html#t:t/0"},{"type":"exception","title":"Autumn.HighlightError","doc":"","ref":"Autumn.HighlightError.html"},{"type":"function","title":"Autumn.HighlightError.message/1","doc":"Callback implementation for  Exception.message/1 .","ref":"Autumn.HighlightError.html#message/1"},{"type":"type","title":"Autumn.HighlightError.t/0","doc":"","ref":"Autumn.HighlightError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.3.3 (2025-05-21) - Changelog","doc":"","ref":"changelog.html#0-3-3-2025-05-21"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add neovim light and dark themes - @mhanberg\n  * Update CSS files\n  * Update `autumnus` to v0.3.2","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.3.2 (2025-04-18) - Changelog","doc":"","ref":"changelog.html#0-3-2-2025-04-18"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added target `arm-unknown-linux-gnueabihf`\n  * Added target `riscv64gc-unknown-linux-gnu`\n  * Added `formatter_schema/0` and `options_schema/0` to expose options schema\n  * Update Autumnus to v0.3.0","ref":"changelog.html#enhancements-1"},{"type":"extras","title":"0.3.1 (2025-04-08) - Changelog","doc":"","ref":"changelog.html#0-3-1-2025-04-08"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Validate options\n  * Update Autumnus to v0.2.0","ref":"changelog.html#enhancements-2"},{"type":"extras","title":"0.3.0 (2025-03-14) - Changelog","doc":"Note this version introduces breaking changes, please open an issue if these changes has caused any issues.\n\n* Now using Neovim themes instead of Helix themes so some themes may look different and others may not be available.\n* Language parsers have been updated so tokens may be different.","ref":"changelog.html#0-3-0-2025-03-14"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Wrap each line in a span tag with the line number, eg: ` ... `\n  * Added a `Terminal` formatter that outputs ANSI escape codes","ref":"changelog.html#enhancements-3"},{"type":"extras","title":"Changed - Changelog","doc":"* Replaced https://crates.io/crates/inkjet with https://crates.io/crates/autumnus\n  * Change class names and structure of the generated HTML","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.5 (2025-01-09) - Changelog","doc":"","ref":"changelog.html#0-2-5-2025-01-09"},{"type":"extras","title":"Fixes - Changelog","doc":"* Escape curly braces with `&lbrace;` and `&rbrace;`","ref":"changelog.html#fixes"},{"type":"extras","title":"Chores - Changelog","doc":"* Update release targets\n  * Update deps","ref":"changelog.html#chores"},{"type":"extras","title":"0.2.4 (2024-12-13) - Changelog","doc":"","ref":"changelog.html#0-2-4-2024-12-13"},{"type":"extras","title":"Fixes - Changelog","doc":"* Escape curly braces to avoid syntax errors on HEEx templates (support LiveView 1.0)","ref":"changelog.html#fixes-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update ex_doc to v0.34","ref":"changelog.html#enhancements-4"},{"type":"extras","title":"Chores - Changelog","doc":"* Bump min required Elixir to v1.13","ref":"changelog.html#chores-1"},{"type":"extras","title":"0.2.3 (2024-04-29) - Changelog","doc":"","ref":"changelog.html#0-2-3-2024-04-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update inkjet to v0.10.5\n  * Add objc language","ref":"changelog.html#enhancements-5"},{"type":"extras","title":"0.2.2 (2024-04-11) - Changelog","doc":"","ref":"changelog.html#0-2-2-2024-04-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add more languages: eex, elm, iex, jsx, ocaml, ocam-interface, svelte, tsx, vim","ref":"changelog.html#enhancements-6"},{"type":"extras","title":"0.2.1 (2024-04-11) - Changelog","doc":"","ref":"changelog.html#0-2-1-2024-04-11"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* Renamed parent ` ` class from `autumn-highlight` to `autumn-hl`\n  * Added prefix `ahl-` to each scope class","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"Fixes - Changelog","doc":"* Include CSS files in package","ref":"changelog.html#fixes-2"},{"type":"extras","title":"0.2.0 (2024-04-10) - Changelog","doc":"","ref":"changelog.html#0-2-0-2024-04-10"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to Inkjet v0.10.4\n  * Update themes\n  * Update languages\n  * Add Pascal language\n  * Add new option `:inline_style` to enable/disable inline styles\n  * Genrate CSS files","ref":"changelog.html#enhancements-7"},{"type":"extras","title":"Fixes - Changelog","doc":"* Name of CSS classes should be unique and composable","ref":"changelog.html#fixes-3"},{"type":"extras","title":"0.1.5 (2023-11-20) - Changelog","doc":"","ref":"changelog.html#0-1-5-2023-11-20"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add themes base16-tomorrow and base16-tomorrow-night - @paradox460","ref":"changelog.html#enhancements-8"},{"type":"extras","title":"0.1.4 (2023-10-25) - Changelog","doc":"","ref":"changelog.html#0-1-4-2023-10-25"},{"type":"extras","title":"Fixes - Changelog","doc":"* Remove newlines to avoid breaking formatting","ref":"changelog.html#fixes-4"},{"type":"extras","title":"0.1.3 (2023-10-24) - Changelog","doc":"","ref":"changelog.html#0-1-3-2023-10-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add translate=\"no\" attr in ` ` tag","ref":"changelog.html#enhancements-9"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix Javascript grammar\n  * Fix Typescript grammar","ref":"changelog.html#fixes-5"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add icon","ref":"changelog.html#enhancements-10"},{"type":"extras","title":"0.1.2 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-2-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add logo","ref":"changelog.html#enhancements-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix broken image links in docs","ref":"changelog.html#fixes-6"},{"type":"extras","title":"0.1.1 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-1-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fallback to plain text on invalid language\n  * Add samples","ref":"changelog.html#enhancements-12"},{"type":"extras","title":"Fixes - Changelog","doc":"* Do not render the first line empty\n  * Make sure languages are loaded correctly","ref":"changelog.html#fixes-7"},{"type":"extras","title":"0.1.0 (2023-09-28) - Changelog","doc":"","ref":"changelog.html#0-1-0-2023-09-28"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Autumn.highlight/3`\n  * Add `Autumn.highlight!/3`","ref":"changelog.html#enhancements-13"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}